import { darkTheme, type GlobalTheme } from "naive-ui";
import { defineStore } from "pinia";

export const useSettingsStore = defineStore(
  "setting",
  () => {
    const isDark = ref(false);
    const theme = computed<GlobalTheme | null>(() =>
      isDark.value ? darkTheme : null
    );

    function toggleTheme() {
      isDark.value = !isDark.value;
    }

    function changeTheme(val: boolean) {
      isDark.value = val;
    }

    return {
      isDark,
      theme,
      toggleTheme,
      changeTheme,
    };
  },
  {
    persist: {
      key: "setting",
      storage: window.localStorage,
    },
  }
);
